require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_addomainfunctionallevel',
  dscmeta_resource_friendly_name: 'ADDomainFunctionalLevel',
  dscmeta_resource_name: 'MSFT_ADDomainFunctionalLevel',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ActiveDirectoryDsc',
  dscmeta_module_version: '6.5.0',
  docs: 'The DSC ADDomainFunctionalLevel resource type.
         Automatically generated from version 6.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_domainidentity: {
      type: 'String',
      desc: 'Specifies the Active Directory domain to modify. You can identify a domain by its distinguished name, GUID, security identifier, DNS domain name, or NetBIOS domain name.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainmode: {
      type: "Enum['Windows2008R2Domain', 'windows2008r2domain', 'Windows2012Domain', 'windows2012domain', 'Windows2012R2Domain', 'windows2012r2domain', 'Windows2016Domain', 'windows2016domain']",
      desc: 'Specifies the functional level for the Active Directory domain.',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
