require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_adfinegrainedpasswordpolicy',
  dscmeta_resource_friendly_name: 'ADFineGrainedPasswordPolicy',
  dscmeta_resource_name: 'MSFT_ADFineGrainedPasswordPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ActiveDirectoryDsc',
  dscmeta_module_version: '6.5.0',
  docs: 'The DSC ADFineGrainedPasswordPolicy resource type.
         Automatically generated from version 6.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_precedence: {
      type: 'Integer[0, 4294967295]',
      desc: 'Specifies a value that defines the precedence of a fine-grained password policy among all fine-grained password policies.',


      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Specifies the description of the object.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'Specifies the display name of the object.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minpasswordlength: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the minimum number of characters that a password must contain.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_complexityenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether password complexity is enabled for the password policy.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies an Active Directory fine-grained password policy object name.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxpasswordage: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum length of time that you can have the same password. The value must be a string representation of a TimeSpan value.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "Specifies whether the fine-grained password policy should be present or absent. Default value is 'Present'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_lockoutobservationwindow: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum time interval between two unsuccessful login attempts before the number of unsuccessful login attempts is reset to 0. The lockout observation window must be smaller than or equal to the lockout duration for a password policy. The value must be a string representation of a TimeSpan value.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_subjects: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the ADPrincipal names the policy is to be applied to, overwrites all existing.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_protectedfromaccidentaldeletion: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to prevent the object from being deleted.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the user account credentials to use to perform this task.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_passwordhistorycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of previous passwords to save.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_domaincontroller: {
      type: 'Optional[String]',
      desc: 'Specifies the Active Directory Domain Services instance to connect to.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_lockoutthreshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of unsuccessful login attempts that are permitted before an account is locked out.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_lockoutduration: {
      type: 'Optional[String]',
      desc: 'Specifies the length of time that an account is locked after the number of failed login attempts exceeds the lockout threshold. The lockout duration must be greater than or equal to the lockout observation time for a password policy. The value must be a string representation of a TimeSpan value.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reversibleencryptionenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the directory must store passwords using reversible encryption.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_minpasswordage: {
      type: 'Optional[String]',
      desc: 'Specifies the minimum length of time before you can change a password. The value must be a string representation of a TimeSpan value.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
