require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_adgroup',
  dscmeta_resource_friendly_name: 'ADGroup',
  dscmeta_resource_name: 'MSFT_ADGroup',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ActiveDirectoryDsc',
  dscmeta_module_version: '6.5.0',
  docs: 'The DSC ADGroup resource type.
         Automatically generated from version 6.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_groupscope: {
      type: "Optional[Enum['DomainLocal', 'domainlocal', 'Global', 'global', 'Universal', 'universal']]",
      desc: "Active Directory group scope. Default value is 'Global'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_restorefromrecyclebin: {
      type: 'Optional[Boolean]',
      desc: 'Try to restore the group from the recycle bin before creating a new one.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the Active Directory group.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'Display name of the Active Directory group.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "Specifies if this Active Directory group should be present or absent. Default value is 'Present'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_membershipattribute: {
      type: "Optional[Enum['SamAccountName', 'samaccountname', 'DistinguishedName', 'distinguishedname', 'ObjectGUID', 'objectguid', 'SID', 'sid']]",
      desc: "Active Directory attribute used to perform membership operations. Default value is 'SamAccountName'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_members: {
      type: 'Optional[Array[String]]',
      desc: 'Active Directory group membership should match membership exactly.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The credential to be used to perform the operation on Active Directory.',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_notes: {
      type: 'Optional[String]',
      desc: 'Active Directory group notes field.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_groupname: {
      type: 'String',
      desc: 'Name of the Active Directory group.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_memberstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Active Directory group should NOT include these members.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_memberstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Active Directory group should include these members.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_category: {
      type: "Optional[Enum['Security', 'security', 'Distribution', 'distribution']]",
      desc: "Active Directory group category. Default value is 'Security'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distinguishedname: {
      type: 'Optional[String]',
      desc: 'Returns the distinguished name of the Active Directory group.',

      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domaincontroller: {
      type: 'Optional[String]',
      desc: 'Active Directory domain controller to enact the change upon.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'Optional[String]',
      desc: 'Location of the group within Active Directory expressed as a Distinguished Name.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_managedby: {
      type: 'Optional[String]',
      desc: 'Active Directory managed by attribute specified as a DistinguishedName.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
