require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_adobjectpermissionentry',
  dscmeta_resource_friendly_name: 'ADObjectPermissionEntry',
  dscmeta_resource_name: 'MSFT_ADObjectPermissionEntry',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ActiveDirectoryDsc',
  dscmeta_module_version: '6.5.0',
  docs: 'The DSC ADObjectPermissionEntry resource type.
         Automatically generated from version 6.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_inheritedobjecttype: {
      type: 'String',
      desc: "The schema GUID of the child object type that can inherit this access rule. If the permission entry shouldn't be restricted to a specific inherited object type, use the zero guid (00000000-0000-0000-0000-000000000000).",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "Indicates if the access will be added (Present) or will be removed (Absent). Default value is 'Present'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_activedirectorysecurityinheritance: {
      type: "Enum['All', 'all', 'Children', 'children', 'Descendents', 'descendents', 'None', 'none', 'SelfAndChildren', 'selfandchildren']",
      desc: "One of the 'ActiveDirectorySecurityInheritance' enumeration values that specifies the inheritance type of the access rule.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_objecttype: {
      type: 'String',
      desc: "The schema GUID of the object to which the access rule applies. If the permission entry shouldn't be restricted to a specific object type, use the zero guid (00000000-0000-0000-0000-000000000000).",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_activedirectoryrights: {
      type: "Optional[Array[Enum['AccessSystemSecurity', 'accesssystemsecurity', 'CreateChild', 'createchild', 'Delete', 'delete', 'DeleteChild', 'deletechild', 'DeleteTree', 'deletetree', 'ExtendedRight', 'extendedright', 'GenericAll', 'genericall', 'GenericExecute', 'genericexecute', 'GenericRead', 'genericread', 'GenericWrite', 'genericwrite', 'ListChildren', 'listchildren', 'ListObject', 'listobject', 'ReadControl', 'readcontrol', 'ReadProperty', 'readproperty', 'Self', 'self', 'Synchronize', 'synchronize', 'WriteDacl', 'writedacl', 'WriteOwner', 'writeowner', 'WriteProperty', 'writeproperty']]]",
      desc: "A combination of one or more of the ActiveDirectoryRights enumeration values that specifies the rights of the access rule. Default value is 'GenericAll'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_accesscontroltype: {
      type: "Enum['Allow', 'allow', 'Deny', 'deny']",
      desc: 'Indicates whether to Allow or Deny access to the target object.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'Active Directory path of the target object to add or remove the permission entry, specified as a Distinguished Name.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_identityreference: {
      type: 'String',
      desc: 'Indicates the identity of the principal for the ACE. Use the notation DOMAIN\SamAccountName for the identity.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
