require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_adreplicationsitelink',
  dscmeta_resource_friendly_name: 'ADReplicationSiteLink',
  dscmeta_resource_name: 'MSFT_ADReplicationSiteLink',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ActiveDirectoryDsc',
  dscmeta_module_version: '6.5.0',
  docs: 'The DSC ADReplicationSiteLink resource type.
         Automatically generated from version 6.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_optiontwowaysync: {
      type: 'Optional[Boolean]',
      desc: 'Enables or disables Two Way Sync on a site link. Default value is $false.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sitesincluded: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the list of sites included in the site link.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "Specifies if the site link should be present or absent. Default value is 'Present'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cost: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the cost to be placed on the site link.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'This parameter sets the value of the Description property for the object.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name of the site link.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitesexcluded: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the list of sites to exclude from the site link.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_optiondisablecompression: {
      type: 'Optional[Boolean]',
      desc: 'Enables or disables Compression on a site link. Default value is $false.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_optionchangenotification: {
      type: 'Optional[Boolean]',
      desc: 'Enables or disables Change Notification Replication on a site link. Default value is $false.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_replicationfrequencyinminutes: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Species the frequency (in minutes) for which replication will occur where this site link is in use between sites.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
  },
)
