require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_adserviceprincipalname',
  dscmeta_resource_friendly_name: 'ADServicePrincipalName',
  dscmeta_resource_name: 'MSFT_ADServicePrincipalName',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ActiveDirectoryDsc',
  dscmeta_module_version: '6.5.0',
  docs: 'The DSC ADServicePrincipalName resource type.
         Automatically generated from version 6.5.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_account: {
      type: 'Optional[String]',
      desc: "The user or computer account to add or remove the SPN to, e.g. User1 or LON-DC1$. Default value is ''. If Ensure is set to Present, a value must be specified.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serviceprincipalname: {
      type: 'String',
      desc: 'The full SPN to add or remove, e.g. HOST/LON-DC1.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "Specifies if the service principal name should be added or removed. Default value is 'Present'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
